@@ -1,11 +1,11 @@
 """A10 support."""
-from __future__ import unicode_literals
 import time
 from netmiko.cisco_base_connection import CiscoSSHConnection
 
 
 class A10SSH(CiscoSSHConnection):
     """A10 support."""
+
     def session_preparation(self):
         """A10 requires to be enable mode to disable paging."""
         self._test_channel_read()
@@ -17,9 +17,9 @@ class A10SSH(CiscoSSHConnection):
         self.set_terminal_width()
 
         # Clear the read buffer
-        time.sleep(.3 * self.global_delay_factor)
+        time.sleep(0.3 * self.global_delay_factor)
         self.clear_buffer()
 
-    def save_config(self, cmd='', confirm=True, confirm_response=''):
+    def save_config(self, *args, **kwargs):
         """Not Implemented"""
         raise NotImplementedError
