@@ -10,6 +10,9 @@ class ArubaSSH(CiscoSSHConnection):
     def __init__(self, **kwargs):
         if kwargs.get("default_enter") is None:
             kwargs["default_enter"] = "\r"
+        # Aruba has an auto-complete on space behavior that is problematic
+        if kwargs.get("global_cmd_verify") is None:
+            kwargs["global_cmd_verify"] = False
         return super().__init__(**kwargs)
 
     def session_preparation(self):
@@ -33,3 +36,9 @@ class ArubaSSH(CiscoSSHConnection):
         if not pattern:
             pattern = re.escape(self.base_prompt[:16])
         return super().check_config_mode(check_string=check_string, pattern=pattern)
+
+    def config_mode(self, config_command="configure term", pattern=""):
+        """
+        Aruba auto completes on space so 'configure' needs fully spelled-out.
+        """
+        return super().config_mode(config_command=config_command, pattern=pattern)
