@@ -1,4 +1,3 @@
-from __future__ import unicode_literals
 from netmiko.cisco_base_connection import CiscoSSHConnection
 
 
@@ -32,13 +31,13 @@ class CoriantSSH(CiscoSSHConnection):
         self, pri_prompt_terminator=":", alt_prompt_terminator=">", delay_factor=2
     ):
         """Sets self.base_prompt: used as delimiter for stripping of trailing prompt in output."""
-        super(CoriantSSH, self).set_base_prompt(
+        super().set_base_prompt(
             pri_prompt_terminator=pri_prompt_terminator,
             alt_prompt_terminator=alt_prompt_terminator,
             delay_factor=delay_factor,
         )
         return self.base_prompt
 
-    def save_config(self, cmd="", confirm=True, confirm_response=""):
+    def save_config(self, *args, **kwargs):
         """Not Implemented"""
         raise NotImplementedError
