@@ -1,4 +1,3 @@
-from __future__ import unicode_literals
 from netmiko.cisco.cisco_ios import (
     CiscoIosBase,
     CiscoIosSSH,
@@ -9,7 +8,7 @@ from netmiko.cisco.cisco_ios import CiscoIosFileTransfer
 from netmiko.cisco.cisco_ios import InLineTransfer
 from netmiko.cisco.cisco_asa_ssh import CiscoAsaSSH, CiscoAsaFileTransfer
 from netmiko.cisco.cisco_nxos_ssh import CiscoNxosSSH, CiscoNxosFileTransfer
-from netmiko.cisco.cisco_xr_ssh import CiscoXrSSH, CiscoXrFileTransfer
+from netmiko.cisco.cisco_xr import CiscoXrSSH, CiscoXrTelnet, CiscoXrFileTransfer
 from netmiko.cisco.cisco_wlc_ssh import CiscoWlcSSH
 from netmiko.cisco.cisco_s300 import CiscoS300SSH
 from netmiko.cisco.cisco_tp_tcce import CiscoTpTcCeSSH
@@ -20,6 +19,7 @@ __all__ = [
     "CiscoAsaSSH",
     "CiscoNxosSSH",
     "CiscoXrSSH",
+    "CiscoXrTelnet",
     "CiscoWlcSSH",
     "CiscoS300SSH",
     "CiscoTpTcCeSSH",
